==> developer-center-api-2.4.8-20170804.085243-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/AppVipLimitDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import java.util.Date;

/**
 * Created by xiaoxuda on 2016/11/15.
 */
public class AppVipLimitDto extends BaseDto{
    private static final long serialVersionUID = 1L;
    public static final int HIDDEN_ITEM = 0;//隐藏不可兑换项
    public static final int GUIDELINES = 1;//在兑换项中进行规则指引

    public static final int USE_DUIBA = 0;//使用兑吧的规则页面
    public static final int USE_YOUSELF = 1;//使用开发者自己的规则页面

    private Long id;
    private Long appId;
    private Integer doMethod;
    private Integer rulePoint;
    private String ruleUrl;
    private String ruleText;

    private Date gmtCreate;
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getDoMethod() {
        return doMethod;
    }

    public void setDoMethod(Integer doMethod) {
        this.doMethod = doMethod;
    }

    public Integer getRulePoint() {
        return rulePoint;
    }

    public void setRulePoint(Integer rulePoint) {
        this.rulePoint = rulePoint;
    }

    public String getRuleUrl() {
        return ruleUrl;
    }

    public void setRuleUrl(String ruleUrl) {
        this.ruleUrl = ruleUrl;
    }

    public String getRuleText() {
        return ruleText;
    }

    public void setRuleText(String ruleText) {
        this.ruleText = ruleText;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> developer-center-api-3.9.18-sources.jar: cn/com/duiba/developer/center/api/domain/dto/AppVipLimitDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import java.util.Date;

/**
 * Created by xiaoxuda on 2016/11/15.
 */
public class AppVipLimitDto extends BaseDto{
    private static final long serialVersionUID = 1L;
    public static final int HIDDEN_ITEM = 0;//隐藏不可兑换项
    public static final int GUIDELINES = 1;//在兑换项中进行规则指引

    public static final int USE_DUIBA = 0;//使用兑吧的规则页面
    public static final int USE_YOUSELF = 1;//使用开发者自己的规则页面

    private Long id;
    private Long appId;
    private Integer doMethod;
    private Integer rulePoint;
    private String ruleUrl;
    private String ruleText;

    private Date gmtCreate;
    private Date gmtModified;

    private String vipRuleUrl; //vip规则说明地址
    private String upgradeText; //升级引导文案
    private String entryText; //会员转化入口文案
    private String vipGoodsIcon; //会员商品图标

    public AppVipLimitDto() {
    }

    public AppVipLimitDto(boolean init4insert) {
        if (init4insert) {
            gmtCreate = new Date();
            gmtModified = new Date();
        }
    }

    public AppVipLimitDto(Long id) {
        this.id = id;
        gmtModified = new Date();
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getDoMethod() {
        return doMethod;
    }

    public void setDoMethod(Integer doMethod) {
        this.doMethod = doMethod;
    }

    public Integer getRulePoint() {
        return rulePoint;
    }

    public void setRulePoint(Integer rulePoint) {
        this.rulePoint = rulePoint;
    }

    public String getRuleUrl() {
        return ruleUrl;
    }

    public void setRuleUrl(String ruleUrl) {
        this.ruleUrl = ruleUrl;
    }

    public String getRuleText() {
        return ruleText;
    }

    public void setRuleText(String ruleText) {
        this.ruleText = ruleText;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getVipRuleUrl() {
        return vipRuleUrl;
    }

    public void setVipRuleUrl(String vipRuleUrl) {
        this.vipRuleUrl = vipRuleUrl;
    }

    public String getUpgradeText() {
        return upgradeText;
    }

    public void setUpgradeText(String upgradeText) {
        this.upgradeText = upgradeText;
    }

    public String getEntryText() {
        return entryText;
    }

    public void setEntryText(String entryText) {
        this.entryText = entryText;
    }

    public String getVipGoodsIcon() {
        return vipGoodsIcon;
    }

    public void setVipGoodsIcon(String vipGoodsIcon) {
        this.vipGoodsIcon = vipGoodsIcon;
    }
}
